﻿#pragma once

struct _EVENT_FILTER_DESCRIPTOR;

void EventCallbackMMaitre_VideoEffects(
    _In_ const GUID* SourceId,
    _In_ ULONG ControlCode,
    _In_ UCHAR Level,
    _In_ ULONGLONG MatchAnyKeyword,
    _In_ ULONGLONG MatchAllKeyword,
    _In_opt_ _EVENT_FILTER_DESCRIPTOR* FilterData,
    _Inout_opt_ PVOID CallbackContext
    );

#define MCGEN_PRIVATE_ENABLE_CALLBACK_V2 EventCallbackMMaitre_VideoEffects

#include "LoggerBase.h"

class __declspec(uuid("{fee63c76-1c45-5a6e-8357-af99fee34832}")) LoggerBase
{
public:

    LoggerBase()
        : m_delayedEventWrite(false)
    {
        EventRegisterMMaitre_VideoEffects();

        if (m_delayedEventWrite)
        {
            EventWriteManifest();
        }
    }

    ~LoggerBase()
    {
        if (MMaitre_VideoEffectsHandle != 0)
        {
            EventWriteManifest();
        }
        EventUnregisterMMaitre_VideoEffects();
    }

    bool IsEnabled()
    {
        return MMaitre_VideoEffects_Context.IsEnabled == EVENT_CONTROL_CODE_ENABLE_PROVIDER;
    }

    void Info(_In_z_ const char* format, ...)
    {
        if (!EventEnabledMMaitre_VideoEffects_Info())
        {
            return;
        }

        char message[1024];

        va_list args;
        va_start(args, format);
        vsprintf_s(message, format, args);
        va_end(args);

        EventWriteMMaitre_VideoEffects_Info(message);
    }

    void Error(_In_z_ const char* format, ...)
    {
        if (!EventEnabledMMaitre_VideoEffects_Error())
        {
            return;
        }

        char message[1024];

        va_list args;
        va_start(args, format);
        vsprintf_s(message, format, args);
        va_end(args);

        EventWriteMMaitre_VideoEffects_Error(message);
    }

    void VideoProcessor_CreateStart()
    {
        EventWriteMMaitre_VideoEffects_VideoProcessor_Create_Start();
    }

    void VideoProcessor_CreateStop(_In_opt_ const void * videoProcessor)
    {
        EventWriteMMaitre_VideoEffects_VideoProcessor_Create_Stop(videoProcessor);
    }

    void LumiaAnalyzer_ProcessStart(_In_opt_ const void * lumiaAnalyzer)
    {
        EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Process_Start(lumiaAnalyzer);
    }

    void LumiaAnalyzer_ProcessStop(_In_opt_ const void * lumiaAnalyzer)
    {
        EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Process_Stop(lumiaAnalyzer);
    }

    void LumiaAnalyzer_ConvertStart(_In_opt_ const void * lumiaAnalyzer, _In_opt_ const void * videoProcessor)
    {
        EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Convert_Start(lumiaAnalyzer, videoProcessor);
    }

    void LumiaAnalyzer_ConvertStop(_In_opt_ const void * lumiaAnalyzer)
    {
        EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Convert_Stop(lumiaAnalyzer);
    }

    void LumiaAnalyzer_AnalyzeStart(_In_opt_ const void * lumiaAnalyzer)
    {
        EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Analyze_Start(lumiaAnalyzer);
    }

    void LumiaAnalyzer_AnalyzeStop(_In_opt_ const void * lumiaAnalyzer)
    {
        EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Analyze_Stop(lumiaAnalyzer);
    }

    void EventDelayedWriteManifest()
    {
        m_delayedEventWrite = true;
    }

    void EventWriteManifest()
    {
        static const char manifest[] =
            R"(<?xml version="1.0" encoding="utf-8"?>
<instrumentationManifest 
  xmlns="http://schemas.microsoft.com/win/2004/08/events"
  xmlns:win="http://manifests.microsoft.com/win/2004/08/windows/events"
  xmlns:xs="http://www.w3.org/2001/XMLSchema"
  >
  <instrumentation>
    <events>
      <provider
        name="MMaitre-VideoEffects"
        symbol="MMaitre_VideoEffects"
        guid="{fee63c76-1c45-5a6e-8357-af99fee34832}"
        resourceFileName="placeholder.dll"
        messageFileName="placeholder.dll"
        >
        <tasks>
          <task value="1" name="Info" />
          <task value="2" name="Error" />
          <task value="3" name="VideoProcessor_Create" />
          <task value="4" name="LumiaAnalyzer_Process" />
          <task value="5" name="LumiaAnalyzer_Convert" />
          <task value="6" name="LumiaAnalyzer_Analyze" />
        </tasks>
        <templates>
          <template tid="template1">
            <data name="Message" inType="win:AnsiString" />
          </template>
          <template tid="template2">
            <data name="Message" inType="win:AnsiString" />
          </template>
          <template tid="template4">
            <data name="VideoProcessor" inType="win:Pointer" />
          </template>
          <template tid="template5">
            <data name="LumiaAnalyzer" inType="win:Pointer" />
          </template>
          <template tid="template6">
            <data name="LumiaAnalyzer" inType="win:Pointer" />
          </template>
          <template tid="template7">
            <data name="LumiaAnalyzer" inType="win:Pointer" />
            <data name="VideoProcessor" inType="win:Pointer" />
          </template>
          <template tid="template8">
            <data name="LumiaAnalyzer" inType="win:Pointer" />
          </template>
          <template tid="template9">
            <data name="LumiaAnalyzer" inType="win:Pointer" />
          </template>
          <template tid="template10">
            <data name="LumiaAnalyzer" inType="win:Pointer" />
          </template>
        </templates>
        <events>
          <event value="1" symbol="MMaitre_VideoEffects_Info" task="Info" opcode="win:Info" level="win:Informational" template="template1" />
          <event value="2" symbol="MMaitre_VideoEffects_Error" task="Error" opcode="win:Info" level="win:Error" template="template2" />
          <event value="3" symbol="MMaitre_VideoEffects_VideoProcessor_Create_Start" task="VideoProcessor_Create" opcode="win:Start" level="win:Informational" />
          <event value="4" symbol="MMaitre_VideoEffects_VideoProcessor_Create_Stop" task="VideoProcessor_Create" opcode="win:Stop" level="win:Informational" template="template4" />
          <event value="5" symbol="MMaitre_VideoEffects_LumiaAnalyzer_Process_Start" task="LumiaAnalyzer_Process" opcode="win:Start" level="win:Informational" template="template5" />
          <event value="6" symbol="MMaitre_VideoEffects_LumiaAnalyzer_Process_Stop" task="LumiaAnalyzer_Process" opcode="win:Stop" level="win:Informational" template="template6" />
          <event value="7" symbol="MMaitre_VideoEffects_LumiaAnalyzer_Convert_Start" task="LumiaAnalyzer_Convert" opcode="win:Start" level="win:Informational" template="template7" />
          <event value="8" symbol="MMaitre_VideoEffects_LumiaAnalyzer_Convert_Stop" task="LumiaAnalyzer_Convert" opcode="win:Stop" level="win:Informational" template="template8" />
          <event value="9" symbol="MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Start" task="LumiaAnalyzer_Analyze" opcode="win:Start" level="win:Informational" template="template9" />
          <event value="10" symbol="MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Stop" task="LumiaAnalyzer_Analyze" opcode="win:Stop" level="win:Informational" template="template10" />
        </events>
      </provider>
    </events>
  </instrumentation>
</instrumentationManifest>)";

        // Currently a single chunk supported
        static_assert(sizeof(manifest) < ManifestEnvelope::MaxChunkSize, "Only one manifest chunk currently supported");

        EVENT_DESCRIPTOR eventDescr = { 0xFFFE, 1, 0, 0, 0xFE, 0xFFFE, -1 };
        ManifestEnvelope envelope = { 1, 1, 0, 0x5B, 1, 0 };

        EVENT_DATA_DESCRIPTOR dataDescr[2] = {};
        dataDescr[0].Ptr = reinterpret_cast<ULONGLONG>(&envelope);
        dataDescr[0].Size = sizeof(envelope);
        dataDescr[1].Ptr = reinterpret_cast<ULONGLONG>(manifest);
        dataDescr[1].Size = sizeof(manifest) - 1;

        ULONG ret = EventWrite(MMaitre_VideoEffectsHandle, &eventDescr, ARRAYSIZE(dataDescr), dataDescr);
#ifndef NDEBUG
        if (ret != ERROR_SUCCESS)
        {
            __debugbreak();
        }
#endif
    }

private:

    #pragma pack(push, 1)
    struct ManifestEnvelope
    {
        uint8_t Format;
        uint8_t MajorVersion;
        uint8_t MinorVersion;
        uint8_t Magic;
        uint16_t TotalChunks;
        uint16_t ChunkNumber;

        static const uint16_t MaxChunkSize = 0xFF00;
    };
    #pragma pack(pop)

    bool m_delayedEventWrite;
};

__declspec(selectany) LoggerBase Logger;

inline void EventCallbackMMaitre_VideoEffects(
    _In_ const GUID* /*SourceId*/,
    _In_ ULONG ControlCode,
    _In_ UCHAR /*Level*/,
    _In_ ULONGLONG /*MatchAnyKeyword*/,
    _In_ ULONGLONG /*MatchAllKeyword*/,
    _In_opt_ _EVENT_FILTER_DESCRIPTOR* /*FilterData*/,
    _Inout_opt_ PVOID /*CallbackContext*/
    )
{
    if (ControlCode == EVENT_CONTROL_CODE_ENABLE_PROVIDER)
    {
        // The callback may be called during the call to EventRegisterXxx(), in which
        // case the handle is not set yet. Manifest will be sent at the end of the
        // constructor after EventRegisterMMaitre_VideoEffects() completes
        if (MMaitre_VideoEffectsHandle != 0)
        {
            Logger.EventWriteManifest();
        }
        else
        {
            Logger.EventDelayedWriteManifest();
        }
    }

    if (ControlCode == EVENT_CONTROL_CODE_DISABLE_PROVIDER)
    {
        Logger.EventWriteManifest();
    }
}