//**********************************************************************`
//* This is an include file generated by Message Compiler.             *`
//*                                                                    *`
//* Copyright (c) Microsoft Corporation. All Rights Reserved.          *`
//**********************************************************************`
#pragma once
#include <wmistr.h>
#include <evntrace.h>
#include "evntprov.h"
//
//  Initial Defs
//
#if !defined(ETW_INLINE)
#define ETW_INLINE DECLSPEC_NOINLINE __inline
#endif

#if defined(__cplusplus)
extern "C" {
#endif

//
// Allow Diasabling of code generation
//
#ifndef MCGEN_DISABLE_PROVIDER_CODE_GENERATION
#if  !defined(McGenDebug)
#define McGenDebug(a,b)
#endif 


#if !defined(MCGEN_TRACE_CONTEXT_DEF)
#define MCGEN_TRACE_CONTEXT_DEF
typedef struct _MCGEN_TRACE_CONTEXT
{
    TRACEHANDLE            RegistrationHandle;
    TRACEHANDLE            Logger;
    ULONGLONG              MatchAnyKeyword;
    ULONGLONG              MatchAllKeyword;
    ULONG                  Flags;
    ULONG                  IsEnabled;
    UCHAR                  Level; 
    UCHAR                  Reserve;
    USHORT                 EnableBitsCount;
    PULONG                 EnableBitMask;
    const ULONGLONG*       EnableKeyWords;
    const UCHAR*           EnableLevel;
} MCGEN_TRACE_CONTEXT, *PMCGEN_TRACE_CONTEXT;
#endif

#if !defined(MCGEN_LEVEL_KEYWORD_ENABLED_DEF)
#define MCGEN_LEVEL_KEYWORD_ENABLED_DEF
FORCEINLINE
BOOLEAN
McGenLevelKeywordEnabled(
    _In_ PMCGEN_TRACE_CONTEXT EnableInfo,
    _In_ UCHAR Level,
    _In_ ULONGLONG Keyword
    )
{
    //
    // Check if the event Level is lower than the level at which
    // the channel is enabled.
    // If the event Level is 0 or the channel is enabled at level 0,
    // all levels are enabled.
    //

    if ((Level <= EnableInfo->Level) || // This also covers the case of Level == 0.
        (EnableInfo->Level == 0)) {

        //
        // Check if Keyword is enabled
        //

        if ((Keyword == (ULONGLONG)0) ||
            ((Keyword & EnableInfo->MatchAnyKeyword) &&
             ((Keyword & EnableInfo->MatchAllKeyword) == EnableInfo->MatchAllKeyword))) {
            return TRUE;
        }
    }

    return FALSE;

}
#endif

#if !defined(MCGEN_EVENT_ENABLED_DEF)
#define MCGEN_EVENT_ENABLED_DEF
FORCEINLINE
BOOLEAN
McGenEventEnabled(
    _In_ PMCGEN_TRACE_CONTEXT EnableInfo,
    _In_ PCEVENT_DESCRIPTOR EventDescriptor
    )
{

    return McGenLevelKeywordEnabled(EnableInfo, EventDescriptor->Level, EventDescriptor->Keyword);

}
#endif


//
// EnableCheckMacro
//
#ifndef MCGEN_ENABLE_CHECK
#define MCGEN_ENABLE_CHECK(Context, Descriptor) (Context.IsEnabled &&  McGenEventEnabled(&Context, &Descriptor))
#endif

#if !defined(MCGEN_CONTROL_CALLBACK)
#define MCGEN_CONTROL_CALLBACK

DECLSPEC_NOINLINE __inline
VOID
__stdcall
McGenControlCallbackV2(
    _In_ LPCGUID SourceId,
    _In_ ULONG ControlCode,
    _In_ UCHAR Level,
    _In_ ULONGLONG MatchAnyKeyword,
    _In_ ULONGLONG MatchAllKeyword,
    _In_opt_ PEVENT_FILTER_DESCRIPTOR FilterData,
    _Inout_opt_ PVOID CallbackContext
    )
/*++

Routine Description:

    This is the notification callback for Vista.

Arguments:

    SourceId - The GUID that identifies the session that enabled the provider. 

    ControlCode - The parameter indicates whether the provider 
                  is being enabled or disabled.

    Level - The level at which the event is enabled.

    MatchAnyKeyword - The bitmask of keywords that the provider uses to 
                      determine the category of events that it writes.

    MatchAllKeyword - This bitmask additionally restricts the category 
                      of events that the provider writes. 

    FilterData - The provider-defined data.

    CallbackContext - The context of the callback that is defined when the provider 
                      called EtwRegister to register itself.

Remarks:

    ETW calls this function to notify provider of enable/disable

--*/
{
    PMCGEN_TRACE_CONTEXT Ctx = (PMCGEN_TRACE_CONTEXT)CallbackContext;
    ULONG Ix;
#ifndef MCGEN_PRIVATE_ENABLE_CALLBACK_V2
    UNREFERENCED_PARAMETER(SourceId);
    UNREFERENCED_PARAMETER(FilterData);
#endif

    if (Ctx == NULL) {
        return;
    }

    switch (ControlCode) {

        case EVENT_CONTROL_CODE_ENABLE_PROVIDER:
            Ctx->Level = Level;
            Ctx->MatchAnyKeyword = MatchAnyKeyword;
            Ctx->MatchAllKeyword = MatchAllKeyword;
            Ctx->IsEnabled = EVENT_CONTROL_CODE_ENABLE_PROVIDER;

            for (Ix = 0; Ix < Ctx->EnableBitsCount; Ix += 1) {
                if (McGenLevelKeywordEnabled(Ctx, Ctx->EnableLevel[Ix], Ctx->EnableKeyWords[Ix]) != FALSE) {
                    Ctx->EnableBitMask[Ix >> 5] |= (1 << (Ix % 32));
                } else {
                    Ctx->EnableBitMask[Ix >> 5] &= ~(1 << (Ix % 32));
                }
            }
            break;

        case EVENT_CONTROL_CODE_DISABLE_PROVIDER:
            Ctx->IsEnabled = EVENT_CONTROL_CODE_DISABLE_PROVIDER;
            Ctx->Level = 0;
            Ctx->MatchAnyKeyword = 0;
            Ctx->MatchAllKeyword = 0;
            if (Ctx->EnableBitsCount > 0) {
                RtlZeroMemory(Ctx->EnableBitMask, (((Ctx->EnableBitsCount - 1) / 32) + 1) * sizeof(ULONG));
            }
            break;
 
        default:
            break;
    }

#ifdef MCGEN_PRIVATE_ENABLE_CALLBACK_V2
    //
    // Call user defined callback
    //
    MCGEN_PRIVATE_ENABLE_CALLBACK_V2(
        SourceId,
        ControlCode,
        Level,
        MatchAnyKeyword,
        MatchAllKeyword,
        FilterData,
        CallbackContext
        );
#endif
   
    return;
}

#endif
#endif // MCGEN_DISABLE_PROVIDER_CODE_GENERATION
//+
// Provider MMaitre-VideoEffects Event Count 10
//+
EXTERN_C __declspec(selectany) const GUID MMaitre_VideoEffects = {0xfee63c76, 0x1c45, 0x5a6e, {0x83, 0x57, 0xaf, 0x99, 0xfe, 0xe3, 0x48, 0x32}};

//
// Tasks
//
#define MMaitre_VideoEffects_TASK_Info 0x1
#define MMaitre_VideoEffects_TASK_Error 0x2
#define MMaitre_VideoEffects_TASK_VideoProcessor_Create 0x3
#define MMaitre_VideoEffects_TASK_LumiaAnalyzer_Process 0x4
#define MMaitre_VideoEffects_TASK_LumiaAnalyzer_Convert 0x5
#define MMaitre_VideoEffects_TASK_LumiaAnalyzer_Analyze 0x6

//
// Event Descriptors
//
EXTERN_C __declspec(selectany) const EVENT_DESCRIPTOR MMaitre_VideoEffects_Info = {0x1, 0x0, 0x0, 0x4, 0x0, 0x1, 0x0};
#define MMaitre_VideoEffects_Info_value 0x1
EXTERN_C __declspec(selectany) const EVENT_DESCRIPTOR MMaitre_VideoEffects_Error = {0x2, 0x0, 0x0, 0x2, 0x0, 0x2, 0x0};
#define MMaitre_VideoEffects_Error_value 0x2
EXTERN_C __declspec(selectany) const EVENT_DESCRIPTOR MMaitre_VideoEffects_VideoProcessor_Create_Start = {0x3, 0x0, 0x0, 0x4, 0x1, 0x3, 0x0};
#define MMaitre_VideoEffects_VideoProcessor_Create_Start_value 0x3
EXTERN_C __declspec(selectany) const EVENT_DESCRIPTOR MMaitre_VideoEffects_VideoProcessor_Create_Stop = {0x4, 0x0, 0x0, 0x4, 0x2, 0x3, 0x0};
#define MMaitre_VideoEffects_VideoProcessor_Create_Stop_value 0x4
EXTERN_C __declspec(selectany) const EVENT_DESCRIPTOR MMaitre_VideoEffects_LumiaAnalyzer_Process_Start = {0x5, 0x0, 0x0, 0x4, 0x1, 0x4, 0x0};
#define MMaitre_VideoEffects_LumiaAnalyzer_Process_Start_value 0x5
EXTERN_C __declspec(selectany) const EVENT_DESCRIPTOR MMaitre_VideoEffects_LumiaAnalyzer_Process_Stop = {0x6, 0x0, 0x0, 0x4, 0x2, 0x4, 0x0};
#define MMaitre_VideoEffects_LumiaAnalyzer_Process_Stop_value 0x6
EXTERN_C __declspec(selectany) const EVENT_DESCRIPTOR MMaitre_VideoEffects_LumiaAnalyzer_Convert_Start = {0x7, 0x0, 0x0, 0x4, 0x1, 0x5, 0x0};
#define MMaitre_VideoEffects_LumiaAnalyzer_Convert_Start_value 0x7
EXTERN_C __declspec(selectany) const EVENT_DESCRIPTOR MMaitre_VideoEffects_LumiaAnalyzer_Convert_Stop = {0x8, 0x0, 0x0, 0x4, 0x2, 0x5, 0x0};
#define MMaitre_VideoEffects_LumiaAnalyzer_Convert_Stop_value 0x8
EXTERN_C __declspec(selectany) const EVENT_DESCRIPTOR MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Start = {0x9, 0x0, 0x0, 0x4, 0x1, 0x6, 0x0};
#define MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Start_value 0x9
EXTERN_C __declspec(selectany) const EVENT_DESCRIPTOR MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Stop = {0xa, 0x0, 0x0, 0x4, 0x2, 0x6, 0x0};
#define MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Stop_value 0xa

//
// Note on Generate Code from Manifest Windows Vista and above
//
//Structures :  are handled as a size and pointer pairs. The macro for the event will have an extra 
//parameter for the size in bytes of the structure. Make sure that your structures have no extra padding.
//
//Strings: There are several cases that can be described in the manifest. For array of variable length 
//strings, the generated code will take the count of characters for the whole array as an input parameter. 
//
//SID No support for array of SIDs, the macro will take a pointer to the SID and use appropriate 
//GetLengthSid function to get the length.
//

//
// Allow Diasabling of code generation
//
#ifndef MCGEN_DISABLE_PROVIDER_CODE_GENERATION

//
// Globals 
//


//
// Event Enablement Bits
//

EXTERN_C __declspec(selectany) DECLSPEC_CACHEALIGN ULONG MMaitre_VideoEffectsEnableBits[1];
EXTERN_C __declspec(selectany) const ULONGLONG MMaitre_VideoEffectsKeywords[2] = {0x0, 0x0};
EXTERN_C __declspec(selectany) const UCHAR MMaitre_VideoEffectsLevels[2] = {4, 2};
EXTERN_C __declspec(selectany) MCGEN_TRACE_CONTEXT MMaitre_VideoEffects_Context = {0, 0, 0, 0, 0, 0, 0, 0, 2, MMaitre_VideoEffectsEnableBits, MMaitre_VideoEffectsKeywords, MMaitre_VideoEffectsLevels};

EXTERN_C __declspec(selectany) REGHANDLE MMaitre_VideoEffectsHandle = (REGHANDLE)0;

#if !defined(McGenEventRegisterUnregister)
#define McGenEventRegisterUnregister
DECLSPEC_NOINLINE __inline
ULONG __stdcall
McGenEventRegister(
    _In_ LPCGUID ProviderId,
    _In_opt_ PENABLECALLBACK EnableCallback,
    _In_opt_ PVOID CallbackContext,
    _Inout_ PREGHANDLE RegHandle
    )
/*++

Routine Description:

    This function register the provider with ETW USER mode.

Arguments:
    ProviderId - Provider Id to be register with ETW.

    EnableCallback - Callback to be used.

    CallbackContext - Context for this provider.

    RegHandle - Pointer to Registration handle.

Remarks:

    If the handle != NULL will return ERROR_SUCCESS

--*/
{
    ULONG Error;


    if (*RegHandle) {
        //
        // already registered
        //
        return ERROR_SUCCESS;
    }

    Error = EventRegister( ProviderId, EnableCallback, CallbackContext, RegHandle); 

    return Error;
}


DECLSPEC_NOINLINE __inline
ULONG __stdcall
McGenEventUnregister(_Inout_ PREGHANDLE RegHandle)
/*++

Routine Description:

    Unregister from ETW USER mode

Arguments:
            RegHandle this is the pointer to the provider context
Remarks:
            If Provider has not register RegHandle = NULL,
            return ERROR_SUCCESS
--*/
{
    ULONG Error;


    if(!(*RegHandle)) {
        //
        // Provider has not registerd
        //
        return ERROR_SUCCESS;
    }

    Error = EventUnregister(*RegHandle); 
    *RegHandle = (REGHANDLE)0;
    
    return Error;
}
#endif
//
// Register with ETW Vista +
//
#ifndef EventRegisterMMaitre_VideoEffects
#define EventRegisterMMaitre_VideoEffects() McGenEventRegister(&MMaitre_VideoEffects, McGenControlCallbackV2, &MMaitre_VideoEffects_Context, &MMaitre_VideoEffectsHandle) 
#endif

//
// UnRegister with ETW
//
#ifndef EventUnregisterMMaitre_VideoEffects
#define EventUnregisterMMaitre_VideoEffects() McGenEventUnregister(&MMaitre_VideoEffectsHandle) 
#endif

//
// Enablement check macro for MMaitre_VideoEffects_Info
//

#define EventEnabledMMaitre_VideoEffects_Info() ((MMaitre_VideoEffectsEnableBits[0] & 0x00000001) != 0)

//
// Event Macro for MMaitre_VideoEffects_Info
//
#define EventWriteMMaitre_VideoEffects_Info(Message)\
        EventEnabledMMaitre_VideoEffects_Info() ?\
        Template_s(MMaitre_VideoEffectsHandle, &MMaitre_VideoEffects_Info, Message)\
        : ERROR_SUCCESS\

//
// Enablement check macro for MMaitre_VideoEffects_Error
//

#define EventEnabledMMaitre_VideoEffects_Error() ((MMaitre_VideoEffectsEnableBits[0] & 0x00000002) != 0)

//
// Event Macro for MMaitre_VideoEffects_Error
//
#define EventWriteMMaitre_VideoEffects_Error(Message)\
        EventEnabledMMaitre_VideoEffects_Error() ?\
        Template_s(MMaitre_VideoEffectsHandle, &MMaitre_VideoEffects_Error, Message)\
        : ERROR_SUCCESS\

//
// Enablement check macro for MMaitre_VideoEffects_VideoProcessor_Create_Start
//

#define EventEnabledMMaitre_VideoEffects_VideoProcessor_Create_Start() ((MMaitre_VideoEffectsEnableBits[0] & 0x00000001) != 0)

//
// Event Macro for MMaitre_VideoEffects_VideoProcessor_Create_Start
//
#define EventWriteMMaitre_VideoEffects_VideoProcessor_Create_Start()\
        EventEnabledMMaitre_VideoEffects_VideoProcessor_Create_Start() ?\
        TemplateEventDescriptor(MMaitre_VideoEffectsHandle, &MMaitre_VideoEffects_VideoProcessor_Create_Start)\
        : ERROR_SUCCESS\

//
// Enablement check macro for MMaitre_VideoEffects_VideoProcessor_Create_Stop
//

#define EventEnabledMMaitre_VideoEffects_VideoProcessor_Create_Stop() ((MMaitre_VideoEffectsEnableBits[0] & 0x00000001) != 0)

//
// Event Macro for MMaitre_VideoEffects_VideoProcessor_Create_Stop
//
#define EventWriteMMaitre_VideoEffects_VideoProcessor_Create_Stop(VideoProcessor)\
        EventEnabledMMaitre_VideoEffects_VideoProcessor_Create_Stop() ?\
        Template_p(MMaitre_VideoEffectsHandle, &MMaitre_VideoEffects_VideoProcessor_Create_Stop, VideoProcessor)\
        : ERROR_SUCCESS\

//
// Enablement check macro for MMaitre_VideoEffects_LumiaAnalyzer_Process_Start
//

#define EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Process_Start() ((MMaitre_VideoEffectsEnableBits[0] & 0x00000001) != 0)

//
// Event Macro for MMaitre_VideoEffects_LumiaAnalyzer_Process_Start
//
#define EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Process_Start(LumiaAnalyzer)\
        EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Process_Start() ?\
        Template_p(MMaitre_VideoEffectsHandle, &MMaitre_VideoEffects_LumiaAnalyzer_Process_Start, LumiaAnalyzer)\
        : ERROR_SUCCESS\

//
// Enablement check macro for MMaitre_VideoEffects_LumiaAnalyzer_Process_Stop
//

#define EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Process_Stop() ((MMaitre_VideoEffectsEnableBits[0] & 0x00000001) != 0)

//
// Event Macro for MMaitre_VideoEffects_LumiaAnalyzer_Process_Stop
//
#define EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Process_Stop(LumiaAnalyzer)\
        EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Process_Stop() ?\
        Template_p(MMaitre_VideoEffectsHandle, &MMaitre_VideoEffects_LumiaAnalyzer_Process_Stop, LumiaAnalyzer)\
        : ERROR_SUCCESS\

//
// Enablement check macro for MMaitre_VideoEffects_LumiaAnalyzer_Convert_Start
//

#define EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Convert_Start() ((MMaitre_VideoEffectsEnableBits[0] & 0x00000001) != 0)

//
// Event Macro for MMaitre_VideoEffects_LumiaAnalyzer_Convert_Start
//
#define EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Convert_Start(LumiaAnalyzer, VideoProcessor)\
        EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Convert_Start() ?\
        Template_pp(MMaitre_VideoEffectsHandle, &MMaitre_VideoEffects_LumiaAnalyzer_Convert_Start, LumiaAnalyzer, VideoProcessor)\
        : ERROR_SUCCESS\

//
// Enablement check macro for MMaitre_VideoEffects_LumiaAnalyzer_Convert_Stop
//

#define EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Convert_Stop() ((MMaitre_VideoEffectsEnableBits[0] & 0x00000001) != 0)

//
// Event Macro for MMaitre_VideoEffects_LumiaAnalyzer_Convert_Stop
//
#define EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Convert_Stop(LumiaAnalyzer)\
        EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Convert_Stop() ?\
        Template_p(MMaitre_VideoEffectsHandle, &MMaitre_VideoEffects_LumiaAnalyzer_Convert_Stop, LumiaAnalyzer)\
        : ERROR_SUCCESS\

//
// Enablement check macro for MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Start
//

#define EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Analyze_Start() ((MMaitre_VideoEffectsEnableBits[0] & 0x00000001) != 0)

//
// Event Macro for MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Start
//
#define EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Analyze_Start(LumiaAnalyzer)\
        EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Analyze_Start() ?\
        Template_p(MMaitre_VideoEffectsHandle, &MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Start, LumiaAnalyzer)\
        : ERROR_SUCCESS\

//
// Enablement check macro for MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Stop
//

#define EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Analyze_Stop() ((MMaitre_VideoEffectsEnableBits[0] & 0x00000001) != 0)

//
// Event Macro for MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Stop
//
#define EventWriteMMaitre_VideoEffects_LumiaAnalyzer_Analyze_Stop(LumiaAnalyzer)\
        EventEnabledMMaitre_VideoEffects_LumiaAnalyzer_Analyze_Stop() ?\
        Template_p(MMaitre_VideoEffectsHandle, &MMaitre_VideoEffects_LumiaAnalyzer_Analyze_Stop, LumiaAnalyzer)\
        : ERROR_SUCCESS\

#endif // MCGEN_DISABLE_PROVIDER_CODE_GENERATION


//
// Allow Diasabling of code generation
//
#ifndef MCGEN_DISABLE_PROVIDER_CODE_GENERATION

//
// Template Functions 
//
//
//Template from manifest : template1
//
#ifndef Template_s_def
#define Template_s_def
ETW_INLINE
ULONG
Template_s(
    _In_ REGHANDLE RegHandle,
    _In_ PCEVENT_DESCRIPTOR Descriptor,
    _In_opt_ LPCSTR  _Arg0
    )
{
#define ARGUMENT_COUNT_s 1

    EVENT_DATA_DESCRIPTOR EventData[ARGUMENT_COUNT_s];

    EventDataDescCreate(&EventData[0], 
                        (_Arg0 != NULL) ? _Arg0 : "NULL",
                        (_Arg0 != NULL) ? (ULONG)((strlen(_Arg0) + 1) * sizeof(CHAR)) : (ULONG)sizeof("NULL"));

    return EventWrite(RegHandle, Descriptor, ARGUMENT_COUNT_s, EventData);
}
#endif

//
//Template from manifest : (null)
//
#ifndef TemplateEventDescriptor_def
#define TemplateEventDescriptor_def


ETW_INLINE
ULONG
TemplateEventDescriptor(
    _In_ REGHANDLE RegHandle,
    _In_ PCEVENT_DESCRIPTOR Descriptor
    )
{
    return EventWrite(RegHandle, Descriptor, 0, NULL);
}
#endif

//
//Template from manifest : template4
//
#ifndef Template_p_def
#define Template_p_def
ETW_INLINE
ULONG
Template_p(
    _In_ REGHANDLE RegHandle,
    _In_ PCEVENT_DESCRIPTOR Descriptor,
    _In_opt_ const void *  _Arg0
    )
{
#define ARGUMENT_COUNT_p 1

    EVENT_DATA_DESCRIPTOR EventData[ARGUMENT_COUNT_p];

    EventDataDescCreate(&EventData[0], &_Arg0, sizeof(PVOID)  );

    return EventWrite(RegHandle, Descriptor, ARGUMENT_COUNT_p, EventData);
}
#endif

//
//Template from manifest : template7
//
#ifndef Template_pp_def
#define Template_pp_def
ETW_INLINE
ULONG
Template_pp(
    _In_ REGHANDLE RegHandle,
    _In_ PCEVENT_DESCRIPTOR Descriptor,
    _In_opt_ const void *  _Arg0,
    _In_opt_ const void *  _Arg1
    )
{
#define ARGUMENT_COUNT_pp 2

    EVENT_DATA_DESCRIPTOR EventData[ARGUMENT_COUNT_pp];

    EventDataDescCreate(&EventData[0], &_Arg0, sizeof(PVOID)  );

    EventDataDescCreate(&EventData[1], &_Arg1, sizeof(PVOID)  );

    return EventWrite(RegHandle, Descriptor, ARGUMENT_COUNT_pp, EventData);
}
#endif

#endif // MCGEN_DISABLE_PROVIDER_CODE_GENERATION

#if defined(__cplusplus)
};
#endif

